# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common get_config new_operation new_request send_request
#' @include fms_service.R
NULL

#' Sets the AWS Firewall Manager administrator account
#'
#' @description
#' Sets the AWS Firewall Manager administrator account. AWS Firewall
#' Manager must be associated with the master account of your AWS
#' organization or associated with a member account that has the
#' appropriate permissions. If the account ID that you submit is not an AWS
#' Organizations master account, AWS Firewall Manager will set the
#' appropriate permissions for the given member account.
#' 
#' The account that you associate with AWS Firewall Manager is called the
#' AWS Firewall Manager administrator account.
#'
#' @usage
#' fms_associate_admin_account(AdminAccount)
#'
#' @param AdminAccount &#91;required&#93; The AWS account ID to associate with AWS Firewall Manager as the AWS
#' Firewall Manager administrator account. This can be an AWS Organizations
#' master account or a member account. For more information about AWS
#' Organizations and master accounts, see [Managing the AWS Accounts in
#' Your
#' Organization](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts.html).
#'
#' @return
#' An empty list.
#'
#' @section Request syntax:
#' ```
#' svc$associate_admin_account(
#'   AdminAccount = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_associate_admin_account
fms_associate_admin_account <- function(AdminAccount) {
  op <- new_operation(
    name = "AssociateAdminAccount",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$associate_admin_account_input(AdminAccount = AdminAccount)
  output <- .fms$associate_admin_account_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$associate_admin_account <- fms_associate_admin_account

#' Permanently deletes an AWS Firewall Manager applications list
#'
#' @description
#' Permanently deletes an AWS Firewall Manager applications list.
#'
#' @usage
#' fms_delete_apps_list(ListId)
#'
#' @param ListId &#91;required&#93; The ID of the applications list that you want to delete. You can
#' retrieve this ID from [`put_apps_list`][fms_put_apps_list],
#' [`list_apps_lists`][fms_list_apps_lists], and
#' [`get_apps_list`][fms_get_apps_list].
#'
#' @return
#' An empty list.
#'
#' @section Request syntax:
#' ```
#' svc$delete_apps_list(
#'   ListId = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_delete_apps_list
fms_delete_apps_list <- function(ListId) {
  op <- new_operation(
    name = "DeleteAppsList",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$delete_apps_list_input(ListId = ListId)
  output <- .fms$delete_apps_list_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$delete_apps_list <- fms_delete_apps_list

#' Deletes an AWS Firewall Manager association with the IAM role and the
#' Amazon Simple Notification Service (SNS) topic that is used to record
#' AWS Firewall Manager SNS logs
#'
#' @description
#' Deletes an AWS Firewall Manager association with the IAM role and the
#' Amazon Simple Notification Service (SNS) topic that is used to record
#' AWS Firewall Manager SNS logs.
#'
#' @usage
#' fms_delete_notification_channel()
#'
#' @return
#' An empty list.
#'
#' @section Request syntax:
#' ```
#' svc$delete_notification_channel()
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_delete_notification_channel
fms_delete_notification_channel <- function() {
  op <- new_operation(
    name = "DeleteNotificationChannel",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$delete_notification_channel_input()
  output <- .fms$delete_notification_channel_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$delete_notification_channel <- fms_delete_notification_channel

#' Permanently deletes an AWS Firewall Manager policy
#'
#' @description
#' Permanently deletes an AWS Firewall Manager policy.
#'
#' @usage
#' fms_delete_policy(PolicyId, DeleteAllPolicyResources)
#'
#' @param PolicyId &#91;required&#93; The ID of the policy that you want to delete. You can retrieve this ID
#' from [`put_policy`][fms_put_policy] and
#' [`list_policies`][fms_list_policies].
#' @param DeleteAllPolicyResources If `True`, the request performs cleanup according to the policy type.
#' 
#' For AWS WAF and Shield Advanced policies, the cleanup does the
#' following:
#' 
#' -   Deletes rule groups created by AWS Firewall Manager
#' 
#' -   Removes web ACLs from in-scope resources
#' 
#' -   Deletes web ACLs that contain no rules or rule groups
#' 
#' For security group policies, the cleanup does the following for each
#' security group in the policy:
#' 
#' -   Disassociates the security group from in-scope resources
#' 
#' -   Deletes the security group if it was created through Firewall
#'     Manager and if it's no longer associated with any resources through
#'     another policy
#' 
#' After the cleanup, in-scope resources are no longer protected by web
#' ACLs in this policy. Protection of out-of-scope resources remains
#' unchanged. Scope is determined by tags that you create and accounts that
#' you associate with the policy. When creating the policy, if you specify
#' that only resources in specific accounts or with specific tags are in
#' scope of the policy, those accounts and resources are handled by the
#' policy. All others are out of scope. If you don't specify tags or
#' accounts, all resources are in scope.
#'
#' @return
#' An empty list.
#'
#' @section Request syntax:
#' ```
#' svc$delete_policy(
#'   PolicyId = "string",
#'   DeleteAllPolicyResources = TRUE|FALSE
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_delete_policy
fms_delete_policy <- function(PolicyId, DeleteAllPolicyResources = NULL) {
  op <- new_operation(
    name = "DeletePolicy",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$delete_policy_input(PolicyId = PolicyId, DeleteAllPolicyResources = DeleteAllPolicyResources)
  output <- .fms$delete_policy_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$delete_policy <- fms_delete_policy

#' Permanently deletes an AWS Firewall Manager protocols list
#'
#' @description
#' Permanently deletes an AWS Firewall Manager protocols list.
#'
#' @usage
#' fms_delete_protocols_list(ListId)
#'
#' @param ListId &#91;required&#93; The ID of the protocols list that you want to delete. You can retrieve
#' this ID from [`put_protocols_list`][fms_put_protocols_list],
#' [`list_protocols_lists`][fms_list_protocols_lists], and
#' `GetProtocolsLost`.
#'
#' @return
#' An empty list.
#'
#' @section Request syntax:
#' ```
#' svc$delete_protocols_list(
#'   ListId = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_delete_protocols_list
fms_delete_protocols_list <- function(ListId) {
  op <- new_operation(
    name = "DeleteProtocolsList",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$delete_protocols_list_input(ListId = ListId)
  output <- .fms$delete_protocols_list_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$delete_protocols_list <- fms_delete_protocols_list

#' Disassociates the account that has been set as the AWS Firewall Manager
#' administrator account
#'
#' @description
#' Disassociates the account that has been set as the AWS Firewall Manager
#' administrator account. To set a different account as the administrator
#' account, you must submit an
#' [`associate_admin_account`][fms_associate_admin_account] request.
#'
#' @usage
#' fms_disassociate_admin_account()
#'
#' @return
#' An empty list.
#'
#' @section Request syntax:
#' ```
#' svc$disassociate_admin_account()
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_disassociate_admin_account
fms_disassociate_admin_account <- function() {
  op <- new_operation(
    name = "DisassociateAdminAccount",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$disassociate_admin_account_input()
  output <- .fms$disassociate_admin_account_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$disassociate_admin_account <- fms_disassociate_admin_account

#' Returns the AWS Organizations master account that is associated with AWS
#' Firewall Manager as the AWS Firewall Manager administrator
#'
#' @description
#' Returns the AWS Organizations master account that is associated with AWS
#' Firewall Manager as the AWS Firewall Manager administrator.
#'
#' @usage
#' fms_get_admin_account()
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   AdminAccount = "string",
#'   RoleStatus = "READY"|"CREATING"|"PENDING_DELETION"|"DELETING"|"DELETED"
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$get_admin_account()
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_get_admin_account
fms_get_admin_account <- function() {
  op <- new_operation(
    name = "GetAdminAccount",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$get_admin_account_input()
  output <- .fms$get_admin_account_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$get_admin_account <- fms_get_admin_account

#' Returns information about the specified AWS Firewall Manager
#' applications list
#'
#' @description
#' Returns information about the specified AWS Firewall Manager
#' applications list.
#'
#' @usage
#' fms_get_apps_list(ListId, DefaultList)
#'
#' @param ListId &#91;required&#93; The ID of the AWS Firewall Manager applications list that you want the
#' details for.
#' @param DefaultList Specifies whether the list to retrieve is a default list owned by AWS
#' Firewall Manager.
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   AppsList = list(
#'     ListId = "string",
#'     ListName = "string",
#'     ListUpdateToken = "string",
#'     CreateTime = as.POSIXct(
#'       "2015-01-01"
#'     ),
#'     LastUpdateTime = as.POSIXct(
#'       "2015-01-01"
#'     ),
#'     AppsList = list(
#'       list(
#'         AppName = "string",
#'         Protocol = "string",
#'         Port = 123
#'       )
#'     ),
#'     PreviousAppsList = list(
#'       list(
#'         list(
#'           AppName = "string",
#'           Protocol = "string",
#'           Port = 123
#'         )
#'       )
#'     )
#'   ),
#'   AppsListArn = "string"
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$get_apps_list(
#'   ListId = "string",
#'   DefaultList = TRUE|FALSE
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_get_apps_list
fms_get_apps_list <- function(ListId, DefaultList = NULL) {
  op <- new_operation(
    name = "GetAppsList",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$get_apps_list_input(ListId = ListId, DefaultList = DefaultList)
  output <- .fms$get_apps_list_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$get_apps_list <- fms_get_apps_list

#' Returns detailed compliance information about the specified member
#' account
#'
#' @description
#' Returns detailed compliance information about the specified member
#' account. Details include resources that are in and out of compliance
#' with the specified policy. Resources are considered noncompliant for AWS
#' WAF and Shield Advanced policies if the specified policy has not been
#' applied to them. Resources are considered noncompliant for security
#' group policies if they are in scope of the policy, they violate one or
#' more of the policy rules, and remediation is disabled or not possible.
#' Resources are considered noncompliant for Network Firewall policies if a
#' firewall is missing in the VPC, if the firewall endpoint isn't set up in
#' an expected Availability Zone and subnet, if a subnet created by the
#' Firewall Manager doesn't have the expected route table, and for
#' modifications to a firewall policy that violate the Firewall Manager
#' policy's rules.
#'
#' @usage
#' fms_get_compliance_detail(PolicyId, MemberAccount)
#'
#' @param PolicyId &#91;required&#93; The ID of the policy that you want to get the details for. `PolicyId` is
#' returned by [`put_policy`][fms_put_policy] and by
#' [`list_policies`][fms_list_policies].
#' @param MemberAccount &#91;required&#93; The AWS account that owns the resources that you want to get the details
#' for.
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   PolicyComplianceDetail = list(
#'     PolicyOwner = "string",
#'     PolicyId = "string",
#'     MemberAccount = "string",
#'     Violators = list(
#'       list(
#'         ResourceId = "string",
#'         ViolationReason = "WEB_ACL_MISSING_RULE_GROUP"|"RESOURCE_MISSING_WEB_ACL"|"RESOURCE_INCORRECT_WEB_ACL"|"RESOURCE_MISSING_SHIELD_PROTECTION"|"RESOURCE_MISSING_WEB_ACL_OR_SHIELD_PROTECTION"|"RESOURCE_MISSING_SECURITY_GROUP"|"RESOURCE_VIOLATES_AUDIT_SECURITY_GROUP"|"SECURITY_GROUP_UNUSED"|"SECURITY_GROUP_REDUNDANT"|"MISSING_FIREWALL"|"MISSING_FIREWALL_SUBNET_IN_AZ"|"MISSING_EXPECTED_ROUTE_TABLE"|"NETWORK_FIREWALL_POLICY_MODIFIED",
#'         ResourceType = "string"
#'       )
#'     ),
#'     EvaluationLimitExceeded = TRUE|FALSE,
#'     ExpiredAt = as.POSIXct(
#'       "2015-01-01"
#'     ),
#'     IssueInfoMap = list(
#'       "string"
#'     )
#'   )
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$get_compliance_detail(
#'   PolicyId = "string",
#'   MemberAccount = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_get_compliance_detail
fms_get_compliance_detail <- function(PolicyId, MemberAccount) {
  op <- new_operation(
    name = "GetComplianceDetail",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$get_compliance_detail_input(PolicyId = PolicyId, MemberAccount = MemberAccount)
  output <- .fms$get_compliance_detail_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$get_compliance_detail <- fms_get_compliance_detail

#' Information about the Amazon Simple Notification Service (SNS) topic
#' that is used to record AWS Firewall Manager SNS logs
#'
#' @description
#' Information about the Amazon Simple Notification Service (SNS) topic
#' that is used to record AWS Firewall Manager SNS logs.
#'
#' @usage
#' fms_get_notification_channel()
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   SnsTopicArn = "string",
#'   SnsRoleName = "string"
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$get_notification_channel()
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_get_notification_channel
fms_get_notification_channel <- function() {
  op <- new_operation(
    name = "GetNotificationChannel",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$get_notification_channel_input()
  output <- .fms$get_notification_channel_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$get_notification_channel <- fms_get_notification_channel

#' Returns information about the specified AWS Firewall Manager policy
#'
#' @description
#' Returns information about the specified AWS Firewall Manager policy.
#'
#' @usage
#' fms_get_policy(PolicyId)
#'
#' @param PolicyId &#91;required&#93; The ID of the AWS Firewall Manager policy that you want the details for.
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   Policy = list(
#'     PolicyId = "string",
#'     PolicyName = "string",
#'     PolicyUpdateToken = "string",
#'     SecurityServicePolicyData = list(
#'       Type = "WAF"|"WAFV2"|"SHIELD_ADVANCED"|"SECURITY_GROUPS_COMMON"|"SECURITY_GROUPS_CONTENT_AUDIT"|"SECURITY_GROUPS_USAGE_AUDIT"|"NETWORK_FIREWALL",
#'       ManagedServiceData = "string"
#'     ),
#'     ResourceType = "string",
#'     ResourceTypeList = list(
#'       "string"
#'     ),
#'     ResourceTags = list(
#'       list(
#'         Key = "string",
#'         Value = "string"
#'       )
#'     ),
#'     ExcludeResourceTags = TRUE|FALSE,
#'     RemediationEnabled = TRUE|FALSE,
#'     IncludeMap = list(
#'       list(
#'         "string"
#'       )
#'     ),
#'     ExcludeMap = list(
#'       list(
#'         "string"
#'       )
#'     )
#'   ),
#'   PolicyArn = "string"
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$get_policy(
#'   PolicyId = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_get_policy
fms_get_policy <- function(PolicyId) {
  op <- new_operation(
    name = "GetPolicy",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$get_policy_input(PolicyId = PolicyId)
  output <- .fms$get_policy_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$get_policy <- fms_get_policy

#' If you created a Shield Advanced policy, returns policy-level attack
#' summary information in the event of a potential DDoS attack
#'
#' @description
#' If you created a Shield Advanced policy, returns policy-level attack
#' summary information in the event of a potential DDoS attack. Other
#' policy types are currently unsupported.
#'
#' @usage
#' fms_get_protection_status(PolicyId, MemberAccountId, StartTime, EndTime,
#'   NextToken, MaxResults)
#'
#' @param PolicyId &#91;required&#93; The ID of the policy for which you want to get the attack information.
#' @param MemberAccountId The AWS account that is in scope of the policy that you want to get the
#' details for.
#' @param StartTime The start of the time period to query for the attacks. This is a
#' `timestamp` type. The request syntax listing indicates a `number` type
#' because the default used by AWS Firewall Manager is Unix time in
#' seconds. However, any valid `timestamp` format is allowed.
#' @param EndTime The end of the time period to query for the attacks. This is a
#' `timestamp` type. The request syntax listing indicates a `number` type
#' because the default used by AWS Firewall Manager is Unix time in
#' seconds. However, any valid `timestamp` format is allowed.
#' @param NextToken If you specify a value for `MaxResults` and you have more objects than
#' the number that you specify for `MaxResults`, AWS Firewall Manager
#' returns a `NextToken` value in the response, which you can use to
#' retrieve another group of objects. For the second and subsequent
#' [`get_protection_status`][fms_get_protection_status] requests, specify
#' the value of `NextToken` from the previous response to get information
#' about another batch of objects.
#' @param MaxResults Specifies the number of objects that you want AWS Firewall Manager to
#' return for this request. If you have more objects than the number that
#' you specify for `MaxResults`, the response includes a `NextToken` value
#' that you can use to get another batch of objects.
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   AdminAccountId = "string",
#'   ServiceType = "WAF"|"WAFV2"|"SHIELD_ADVANCED"|"SECURITY_GROUPS_COMMON"|"SECURITY_GROUPS_CONTENT_AUDIT"|"SECURITY_GROUPS_USAGE_AUDIT"|"NETWORK_FIREWALL",
#'   Data = "string",
#'   NextToken = "string"
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$get_protection_status(
#'   PolicyId = "string",
#'   MemberAccountId = "string",
#'   StartTime = as.POSIXct(
#'     "2015-01-01"
#'   ),
#'   EndTime = as.POSIXct(
#'     "2015-01-01"
#'   ),
#'   NextToken = "string",
#'   MaxResults = 123
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_get_protection_status
fms_get_protection_status <- function(PolicyId, MemberAccountId = NULL, StartTime = NULL, EndTime = NULL, NextToken = NULL, MaxResults = NULL) {
  op <- new_operation(
    name = "GetProtectionStatus",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$get_protection_status_input(PolicyId = PolicyId, MemberAccountId = MemberAccountId, StartTime = StartTime, EndTime = EndTime, NextToken = NextToken, MaxResults = MaxResults)
  output <- .fms$get_protection_status_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$get_protection_status <- fms_get_protection_status

#' Returns information about the specified AWS Firewall Manager protocols
#' list
#'
#' @description
#' Returns information about the specified AWS Firewall Manager protocols
#' list.
#'
#' @usage
#' fms_get_protocols_list(ListId, DefaultList)
#'
#' @param ListId &#91;required&#93; The ID of the AWS Firewall Manager protocols list that you want the
#' details for.
#' @param DefaultList Specifies whether the list to retrieve is a default list owned by AWS
#' Firewall Manager.
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   ProtocolsList = list(
#'     ListId = "string",
#'     ListName = "string",
#'     ListUpdateToken = "string",
#'     CreateTime = as.POSIXct(
#'       "2015-01-01"
#'     ),
#'     LastUpdateTime = as.POSIXct(
#'       "2015-01-01"
#'     ),
#'     ProtocolsList = list(
#'       "string"
#'     ),
#'     PreviousProtocolsList = list(
#'       list(
#'         "string"
#'       )
#'     )
#'   ),
#'   ProtocolsListArn = "string"
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$get_protocols_list(
#'   ListId = "string",
#'   DefaultList = TRUE|FALSE
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_get_protocols_list
fms_get_protocols_list <- function(ListId, DefaultList = NULL) {
  op <- new_operation(
    name = "GetProtocolsList",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$get_protocols_list_input(ListId = ListId, DefaultList = DefaultList)
  output <- .fms$get_protocols_list_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$get_protocols_list <- fms_get_protocols_list

#' Retrieves violations for a resource based on the specified AWS Firewall
#' Manager policy and AWS account
#'
#' @description
#' Retrieves violations for a resource based on the specified AWS Firewall
#' Manager policy and AWS account.
#'
#' @usage
#' fms_get_violation_details(PolicyId, MemberAccount, ResourceId,
#'   ResourceType)
#'
#' @param PolicyId &#91;required&#93; The ID of the AWS Firewall Manager policy that you want the details for.
#' This currently only supports security group content audit policies.
#' @param MemberAccount &#91;required&#93; The AWS account ID that you want the details for.
#' @param ResourceId &#91;required&#93; The ID of the resource that has violations.
#' @param ResourceType &#91;required&#93; The resource type. This is in the format shown in the [AWS Resource
#' Types
#' Reference](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-template-resource-type-ref.html).
#' Supported resource types are: `AWS::EC2::Instance`,
#' `AWS::EC2::NetworkInterface`, `AWS::EC2::SecurityGroup`,
#' `AWS::NetworkFirewall::FirewallPolicy`, and `AWS::EC2::Subnet`.
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   ViolationDetail = list(
#'     PolicyId = "string",
#'     MemberAccount = "string",
#'     ResourceId = "string",
#'     ResourceType = "string",
#'     ResourceViolations = list(
#'       list(
#'         AwsVPCSecurityGroupViolation = list(
#'           ViolationTarget = "string",
#'           ViolationTargetDescription = "string",
#'           PartialMatches = list(
#'             list(
#'               Reference = "string",
#'               TargetViolationReasons = list(
#'                 "string"
#'               )
#'             )
#'           ),
#'           PossibleSecurityGroupRemediationActions = list(
#'             list(
#'               RemediationActionType = "REMOVE"|"MODIFY",
#'               Description = "string",
#'               RemediationResult = list(
#'                 IPV4Range = "string",
#'                 IPV6Range = "string",
#'                 PrefixListId = "string",
#'                 Protocol = "string",
#'                 FromPort = 123,
#'                 ToPort = 123
#'               ),
#'               IsDefaultAction = TRUE|FALSE
#'             )
#'           )
#'         ),
#'         AwsEc2NetworkInterfaceViolation = list(
#'           ViolationTarget = "string",
#'           ViolatingSecurityGroups = list(
#'             "string"
#'           )
#'         ),
#'         AwsEc2InstanceViolation = list(
#'           ViolationTarget = "string",
#'           AwsEc2NetworkInterfaceViolations = list(
#'             list(
#'               ViolationTarget = "string",
#'               ViolatingSecurityGroups = list(
#'                 "string"
#'               )
#'             )
#'           )
#'         ),
#'         NetworkFirewallMissingFirewallViolation = list(
#'           ViolationTarget = "string",
#'           VPC = "string",
#'           AvailabilityZone = "string",
#'           TargetViolationReason = "string"
#'         ),
#'         NetworkFirewallMissingSubnetViolation = list(
#'           ViolationTarget = "string",
#'           VPC = "string",
#'           AvailabilityZone = "string",
#'           TargetViolationReason = "string"
#'         ),
#'         NetworkFirewallMissingExpectedRTViolation = list(
#'           ViolationTarget = "string",
#'           VPC = "string",
#'           AvailabilityZone = "string",
#'           CurrentRouteTable = "string",
#'           ExpectedRouteTable = "string"
#'         ),
#'         NetworkFirewallPolicyModifiedViolation = list(
#'           ViolationTarget = "string",
#'           CurrentPolicyDescription = list(
#'             StatelessRuleGroups = list(
#'               list(
#'                 RuleGroupName = "string",
#'                 ResourceId = "string",
#'                 Priority = 123
#'               )
#'             ),
#'             StatelessDefaultActions = list(
#'               "string"
#'             ),
#'             StatelessFragmentDefaultActions = list(
#'               "string"
#'             ),
#'             StatelessCustomActions = list(
#'               "string"
#'             ),
#'             StatefulRuleGroups = list(
#'               list(
#'                 RuleGroupName = "string",
#'                 ResourceId = "string"
#'               )
#'             )
#'           ),
#'           ExpectedPolicyDescription = list(
#'             StatelessRuleGroups = list(
#'               list(
#'                 RuleGroupName = "string",
#'                 ResourceId = "string",
#'                 Priority = 123
#'               )
#'             ),
#'             StatelessDefaultActions = list(
#'               "string"
#'             ),
#'             StatelessFragmentDefaultActions = list(
#'               "string"
#'             ),
#'             StatelessCustomActions = list(
#'               "string"
#'             ),
#'             StatefulRuleGroups = list(
#'               list(
#'                 RuleGroupName = "string",
#'                 ResourceId = "string"
#'               )
#'             )
#'           )
#'         )
#'       )
#'     ),
#'     ResourceTags = list(
#'       list(
#'         Key = "string",
#'         Value = "string"
#'       )
#'     ),
#'     ResourceDescription = "string"
#'   )
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$get_violation_details(
#'   PolicyId = "string",
#'   MemberAccount = "string",
#'   ResourceId = "string",
#'   ResourceType = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_get_violation_details
fms_get_violation_details <- function(PolicyId, MemberAccount, ResourceId, ResourceType) {
  op <- new_operation(
    name = "GetViolationDetails",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$get_violation_details_input(PolicyId = PolicyId, MemberAccount = MemberAccount, ResourceId = ResourceId, ResourceType = ResourceType)
  output <- .fms$get_violation_details_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$get_violation_details <- fms_get_violation_details

#' Returns an array of AppsListDataSummary objects
#'
#' @description
#' Returns an array of `AppsListDataSummary` objects.
#'
#' @usage
#' fms_list_apps_lists(DefaultLists, NextToken, MaxResults)
#'
#' @param DefaultLists Specifies whether the lists to retrieve are default lists owned by AWS
#' Firewall Manager.
#' @param NextToken If you specify a value for `MaxResults` in your list request, and you
#' have more objects than the maximum, AWS Firewall Manager returns this
#' token in the response. For all but the first request, you provide the
#' token returned by the prior request in the request parameters, to
#' retrieve the next batch of objects.
#' @param MaxResults &#91;required&#93; The maximum number of objects that you want AWS Firewall Manager to
#' return for this request. If more objects are available, in the response,
#' AWS Firewall Manager provides a `NextToken` value that you can use in a
#' subsequent call to get the next batch of objects.
#' 
#' If you don't specify this, AWS Firewall Manager returns all available
#' objects.
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   AppsLists = list(
#'     list(
#'       ListArn = "string",
#'       ListId = "string",
#'       ListName = "string",
#'       AppsList = list(
#'         list(
#'           AppName = "string",
#'           Protocol = "string",
#'           Port = 123
#'         )
#'       )
#'     )
#'   ),
#'   NextToken = "string"
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$list_apps_lists(
#'   DefaultLists = TRUE|FALSE,
#'   NextToken = "string",
#'   MaxResults = 123
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_list_apps_lists
fms_list_apps_lists <- function(DefaultLists = NULL, NextToken = NULL, MaxResults) {
  op <- new_operation(
    name = "ListAppsLists",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$list_apps_lists_input(DefaultLists = DefaultLists, NextToken = NextToken, MaxResults = MaxResults)
  output <- .fms$list_apps_lists_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$list_apps_lists <- fms_list_apps_lists

#' Returns an array of PolicyComplianceStatus objects
#'
#' @description
#' Returns an array of `PolicyComplianceStatus` objects. Use
#' `PolicyComplianceStatus` to get a summary of which member accounts are
#' protected by the specified policy.
#'
#' @usage
#' fms_list_compliance_status(PolicyId, NextToken, MaxResults)
#'
#' @param PolicyId &#91;required&#93; The ID of the AWS Firewall Manager policy that you want the details for.
#' @param NextToken If you specify a value for `MaxResults` and you have more
#' `PolicyComplianceStatus` objects than the number that you specify for
#' `MaxResults`, AWS Firewall Manager returns a `NextToken` value in the
#' response that allows you to list another group of
#' `PolicyComplianceStatus` objects. For the second and subsequent
#' [`list_compliance_status`][fms_list_compliance_status] requests, specify
#' the value of `NextToken` from the previous response to get information
#' about another batch of `PolicyComplianceStatus` objects.
#' @param MaxResults Specifies the number of `PolicyComplianceStatus` objects that you want
#' AWS Firewall Manager to return for this request. If you have more
#' `PolicyComplianceStatus` objects than the number that you specify for
#' `MaxResults`, the response includes a `NextToken` value that you can use
#' to get another batch of `PolicyComplianceStatus` objects.
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   PolicyComplianceStatusList = list(
#'     list(
#'       PolicyOwner = "string",
#'       PolicyId = "string",
#'       PolicyName = "string",
#'       MemberAccount = "string",
#'       EvaluationResults = list(
#'         list(
#'           ComplianceStatus = "COMPLIANT"|"NON_COMPLIANT",
#'           ViolatorCount = 123,
#'           EvaluationLimitExceeded = TRUE|FALSE
#'         )
#'       ),
#'       LastUpdated = as.POSIXct(
#'         "2015-01-01"
#'       ),
#'       IssueInfoMap = list(
#'         "string"
#'       )
#'     )
#'   ),
#'   NextToken = "string"
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$list_compliance_status(
#'   PolicyId = "string",
#'   NextToken = "string",
#'   MaxResults = 123
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_list_compliance_status
fms_list_compliance_status <- function(PolicyId, NextToken = NULL, MaxResults = NULL) {
  op <- new_operation(
    name = "ListComplianceStatus",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$list_compliance_status_input(PolicyId = PolicyId, NextToken = NextToken, MaxResults = MaxResults)
  output <- .fms$list_compliance_status_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$list_compliance_status <- fms_list_compliance_status

#' Returns a MemberAccounts object that lists the member accounts in the
#' administrator's AWS organization
#'
#' @description
#' Returns a `MemberAccounts` object that lists the member accounts in the
#' administrator's AWS organization.
#' 
#' The [`list_member_accounts`][fms_list_member_accounts] must be submitted
#' by the account that is set as the AWS Firewall Manager administrator.
#'
#' @usage
#' fms_list_member_accounts(NextToken, MaxResults)
#'
#' @param NextToken If you specify a value for `MaxResults` and you have more account IDs
#' than the number that you specify for `MaxResults`, AWS Firewall Manager
#' returns a `NextToken` value in the response that allows you to list
#' another group of IDs. For the second and subsequent
#' `ListMemberAccountsRequest` requests, specify the value of `NextToken`
#' from the previous response to get information about another batch of
#' member account IDs.
#' @param MaxResults Specifies the number of member account IDs that you want AWS Firewall
#' Manager to return for this request. If you have more IDs than the number
#' that you specify for `MaxResults`, the response includes a `NextToken`
#' value that you can use to get another batch of member account IDs.
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   MemberAccounts = list(
#'     "string"
#'   ),
#'   NextToken = "string"
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$list_member_accounts(
#'   NextToken = "string",
#'   MaxResults = 123
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_list_member_accounts
fms_list_member_accounts <- function(NextToken = NULL, MaxResults = NULL) {
  op <- new_operation(
    name = "ListMemberAccounts",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$list_member_accounts_input(NextToken = NextToken, MaxResults = MaxResults)
  output <- .fms$list_member_accounts_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$list_member_accounts <- fms_list_member_accounts

#' Returns an array of PolicySummary objects
#'
#' @description
#' Returns an array of `PolicySummary` objects.
#'
#' @usage
#' fms_list_policies(NextToken, MaxResults)
#'
#' @param NextToken If you specify a value for `MaxResults` and you have more
#' `PolicySummary` objects than the number that you specify for
#' `MaxResults`, AWS Firewall Manager returns a `NextToken` value in the
#' response that allows you to list another group of `PolicySummary`
#' objects. For the second and subsequent
#' [`list_policies`][fms_list_policies] requests, specify the value of
#' `NextToken` from the previous response to get information about another
#' batch of `PolicySummary` objects.
#' @param MaxResults Specifies the number of `PolicySummary` objects that you want AWS
#' Firewall Manager to return for this request. If you have more
#' `PolicySummary` objects than the number that you specify for
#' `MaxResults`, the response includes a `NextToken` value that you can use
#' to get another batch of `PolicySummary` objects.
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   PolicyList = list(
#'     list(
#'       PolicyArn = "string",
#'       PolicyId = "string",
#'       PolicyName = "string",
#'       ResourceType = "string",
#'       SecurityServiceType = "WAF"|"WAFV2"|"SHIELD_ADVANCED"|"SECURITY_GROUPS_COMMON"|"SECURITY_GROUPS_CONTENT_AUDIT"|"SECURITY_GROUPS_USAGE_AUDIT"|"NETWORK_FIREWALL",
#'       RemediationEnabled = TRUE|FALSE
#'     )
#'   ),
#'   NextToken = "string"
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$list_policies(
#'   NextToken = "string",
#'   MaxResults = 123
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_list_policies
fms_list_policies <- function(NextToken = NULL, MaxResults = NULL) {
  op <- new_operation(
    name = "ListPolicies",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$list_policies_input(NextToken = NextToken, MaxResults = MaxResults)
  output <- .fms$list_policies_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$list_policies <- fms_list_policies

#' Returns an array of ProtocolsListDataSummary objects
#'
#' @description
#' Returns an array of `ProtocolsListDataSummary` objects.
#'
#' @usage
#' fms_list_protocols_lists(DefaultLists, NextToken, MaxResults)
#'
#' @param DefaultLists Specifies whether the lists to retrieve are default lists owned by AWS
#' Firewall Manager.
#' @param NextToken If you specify a value for `MaxResults` in your list request, and you
#' have more objects than the maximum, AWS Firewall Manager returns this
#' token in the response. For all but the first request, you provide the
#' token returned by the prior request in the request parameters, to
#' retrieve the next batch of objects.
#' @param MaxResults &#91;required&#93; The maximum number of objects that you want AWS Firewall Manager to
#' return for this request. If more objects are available, in the response,
#' AWS Firewall Manager provides a `NextToken` value that you can use in a
#' subsequent call to get the next batch of objects.
#' 
#' If you don't specify this, AWS Firewall Manager returns all available
#' objects.
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   ProtocolsLists = list(
#'     list(
#'       ListArn = "string",
#'       ListId = "string",
#'       ListName = "string",
#'       ProtocolsList = list(
#'         "string"
#'       )
#'     )
#'   ),
#'   NextToken = "string"
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$list_protocols_lists(
#'   DefaultLists = TRUE|FALSE,
#'   NextToken = "string",
#'   MaxResults = 123
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_list_protocols_lists
fms_list_protocols_lists <- function(DefaultLists = NULL, NextToken = NULL, MaxResults) {
  op <- new_operation(
    name = "ListProtocolsLists",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$list_protocols_lists_input(DefaultLists = DefaultLists, NextToken = NextToken, MaxResults = MaxResults)
  output <- .fms$list_protocols_lists_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$list_protocols_lists <- fms_list_protocols_lists

#' Retrieves the list of tags for the specified AWS resource
#'
#' @description
#' Retrieves the list of tags for the specified AWS resource.
#'
#' @usage
#' fms_list_tags_for_resource(ResourceArn)
#'
#' @param ResourceArn &#91;required&#93; The Amazon Resource Name (ARN) of the resource to return tags for. The
#' AWS Firewall Manager resources that support tagging are policies,
#' applications lists, and protocols lists.
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   TagList = list(
#'     list(
#'       Key = "string",
#'       Value = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$list_tags_for_resource(
#'   ResourceArn = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_list_tags_for_resource
fms_list_tags_for_resource <- function(ResourceArn) {
  op <- new_operation(
    name = "ListTagsForResource",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$list_tags_for_resource_input(ResourceArn = ResourceArn)
  output <- .fms$list_tags_for_resource_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$list_tags_for_resource <- fms_list_tags_for_resource

#' Creates an AWS Firewall Manager applications list
#'
#' @description
#' Creates an AWS Firewall Manager applications list.
#'
#' @usage
#' fms_put_apps_list(AppsList, TagList)
#'
#' @param AppsList &#91;required&#93; The details of the AWS Firewall Manager applications list to be created.
#' @param TagList The tags associated with the resource.
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   AppsList = list(
#'     ListId = "string",
#'     ListName = "string",
#'     ListUpdateToken = "string",
#'     CreateTime = as.POSIXct(
#'       "2015-01-01"
#'     ),
#'     LastUpdateTime = as.POSIXct(
#'       "2015-01-01"
#'     ),
#'     AppsList = list(
#'       list(
#'         AppName = "string",
#'         Protocol = "string",
#'         Port = 123
#'       )
#'     ),
#'     PreviousAppsList = list(
#'       list(
#'         list(
#'           AppName = "string",
#'           Protocol = "string",
#'           Port = 123
#'         )
#'       )
#'     )
#'   ),
#'   AppsListArn = "string"
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$put_apps_list(
#'   AppsList = list(
#'     ListId = "string",
#'     ListName = "string",
#'     ListUpdateToken = "string",
#'     CreateTime = as.POSIXct(
#'       "2015-01-01"
#'     ),
#'     LastUpdateTime = as.POSIXct(
#'       "2015-01-01"
#'     ),
#'     AppsList = list(
#'       list(
#'         AppName = "string",
#'         Protocol = "string",
#'         Port = 123
#'       )
#'     ),
#'     PreviousAppsList = list(
#'       list(
#'         list(
#'           AppName = "string",
#'           Protocol = "string",
#'           Port = 123
#'         )
#'       )
#'     )
#'   ),
#'   TagList = list(
#'     list(
#'       Key = "string",
#'       Value = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_put_apps_list
fms_put_apps_list <- function(AppsList, TagList = NULL) {
  op <- new_operation(
    name = "PutAppsList",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$put_apps_list_input(AppsList = AppsList, TagList = TagList)
  output <- .fms$put_apps_list_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$put_apps_list <- fms_put_apps_list

#' Designates the IAM role and Amazon Simple Notification Service (SNS)
#' topic that AWS Firewall Manager uses to record SNS logs
#'
#' @description
#' Designates the IAM role and Amazon Simple Notification Service (SNS)
#' topic that AWS Firewall Manager uses to record SNS logs.
#' 
#' To perform this action outside of the console, you must configure the
#' SNS topic to allow the Firewall Manager role `AWSServiceRoleForFMS` to
#' publish SNS logs. For more information, see [Firewall Manager required
#' permissions for API
#' actions](https://docs.aws.amazon.com/waf/latest/developerguide/fms-api-permissions-ref.html)
#' in the *AWS Firewall Manager Developer Guide*.
#'
#' @usage
#' fms_put_notification_channel(SnsTopicArn, SnsRoleName)
#'
#' @param SnsTopicArn &#91;required&#93; The Amazon Resource Name (ARN) of the SNS topic that collects
#' notifications from AWS Firewall Manager.
#' @param SnsRoleName &#91;required&#93; The Amazon Resource Name (ARN) of the IAM role that allows Amazon SNS to
#' record AWS Firewall Manager activity.
#'
#' @return
#' An empty list.
#'
#' @section Request syntax:
#' ```
#' svc$put_notification_channel(
#'   SnsTopicArn = "string",
#'   SnsRoleName = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_put_notification_channel
fms_put_notification_channel <- function(SnsTopicArn, SnsRoleName) {
  op <- new_operation(
    name = "PutNotificationChannel",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$put_notification_channel_input(SnsTopicArn = SnsTopicArn, SnsRoleName = SnsRoleName)
  output <- .fms$put_notification_channel_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$put_notification_channel <- fms_put_notification_channel

#' Creates an AWS Firewall Manager policy
#'
#' @description
#' Creates an AWS Firewall Manager policy.
#' 
#' Firewall Manager provides the following types of policies:
#' 
#' -   An AWS WAF policy (type WAFV2), which defines rule groups to run
#'     first in the corresponding AWS WAF web ACL and rule groups to run
#'     last in the web ACL.
#' 
#' -   An AWS WAF Classic policy (type WAF), which defines a rule group.
#' 
#' -   A Shield Advanced policy, which applies Shield Advanced protection
#'     to specified accounts and resources.
#' 
#' -   A security group policy, which manages VPC security groups across
#'     your AWS organization.
#' 
#' -   An AWS Network Firewall policy, which provides firewall rules to
#'     filter network traffic in specified Amazon VPCs.
#' 
#' Each policy is specific to one of the types. If you want to enforce more
#' than one policy type across accounts, create multiple policies. You can
#' create multiple policies for each type.
#' 
#' You must be subscribed to Shield Advanced to create a Shield Advanced
#' policy. For more information about subscribing to Shield Advanced, see
#' [CreateSubscription](https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_CreateSubscription.html).
#'
#' @usage
#' fms_put_policy(Policy, TagList)
#'
#' @param Policy &#91;required&#93; The details of the AWS Firewall Manager policy to be created.
#' @param TagList The tags to add to the AWS resource.
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   Policy = list(
#'     PolicyId = "string",
#'     PolicyName = "string",
#'     PolicyUpdateToken = "string",
#'     SecurityServicePolicyData = list(
#'       Type = "WAF"|"WAFV2"|"SHIELD_ADVANCED"|"SECURITY_GROUPS_COMMON"|"SECURITY_GROUPS_CONTENT_AUDIT"|"SECURITY_GROUPS_USAGE_AUDIT"|"NETWORK_FIREWALL",
#'       ManagedServiceData = "string"
#'     ),
#'     ResourceType = "string",
#'     ResourceTypeList = list(
#'       "string"
#'     ),
#'     ResourceTags = list(
#'       list(
#'         Key = "string",
#'         Value = "string"
#'       )
#'     ),
#'     ExcludeResourceTags = TRUE|FALSE,
#'     RemediationEnabled = TRUE|FALSE,
#'     IncludeMap = list(
#'       list(
#'         "string"
#'       )
#'     ),
#'     ExcludeMap = list(
#'       list(
#'         "string"
#'       )
#'     )
#'   ),
#'   PolicyArn = "string"
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$put_policy(
#'   Policy = list(
#'     PolicyId = "string",
#'     PolicyName = "string",
#'     PolicyUpdateToken = "string",
#'     SecurityServicePolicyData = list(
#'       Type = "WAF"|"WAFV2"|"SHIELD_ADVANCED"|"SECURITY_GROUPS_COMMON"|"SECURITY_GROUPS_CONTENT_AUDIT"|"SECURITY_GROUPS_USAGE_AUDIT"|"NETWORK_FIREWALL",
#'       ManagedServiceData = "string"
#'     ),
#'     ResourceType = "string",
#'     ResourceTypeList = list(
#'       "string"
#'     ),
#'     ResourceTags = list(
#'       list(
#'         Key = "string",
#'         Value = "string"
#'       )
#'     ),
#'     ExcludeResourceTags = TRUE|FALSE,
#'     RemediationEnabled = TRUE|FALSE,
#'     IncludeMap = list(
#'       list(
#'         "string"
#'       )
#'     ),
#'     ExcludeMap = list(
#'       list(
#'         "string"
#'       )
#'     )
#'   ),
#'   TagList = list(
#'     list(
#'       Key = "string",
#'       Value = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_put_policy
fms_put_policy <- function(Policy, TagList = NULL) {
  op <- new_operation(
    name = "PutPolicy",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$put_policy_input(Policy = Policy, TagList = TagList)
  output <- .fms$put_policy_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$put_policy <- fms_put_policy

#' Creates an AWS Firewall Manager protocols list
#'
#' @description
#' Creates an AWS Firewall Manager protocols list.
#'
#' @usage
#' fms_put_protocols_list(ProtocolsList, TagList)
#'
#' @param ProtocolsList &#91;required&#93; The details of the AWS Firewall Manager protocols list to be created.
#' @param TagList The tags associated with the resource.
#'
#' @return
#' A list with the following syntax:
#' ```
#' list(
#'   ProtocolsList = list(
#'     ListId = "string",
#'     ListName = "string",
#'     ListUpdateToken = "string",
#'     CreateTime = as.POSIXct(
#'       "2015-01-01"
#'     ),
#'     LastUpdateTime = as.POSIXct(
#'       "2015-01-01"
#'     ),
#'     ProtocolsList = list(
#'       "string"
#'     ),
#'     PreviousProtocolsList = list(
#'       list(
#'         "string"
#'       )
#'     )
#'   ),
#'   ProtocolsListArn = "string"
#' )
#' ```
#'
#' @section Request syntax:
#' ```
#' svc$put_protocols_list(
#'   ProtocolsList = list(
#'     ListId = "string",
#'     ListName = "string",
#'     ListUpdateToken = "string",
#'     CreateTime = as.POSIXct(
#'       "2015-01-01"
#'     ),
#'     LastUpdateTime = as.POSIXct(
#'       "2015-01-01"
#'     ),
#'     ProtocolsList = list(
#'       "string"
#'     ),
#'     PreviousProtocolsList = list(
#'       list(
#'         "string"
#'       )
#'     )
#'   ),
#'   TagList = list(
#'     list(
#'       Key = "string",
#'       Value = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_put_protocols_list
fms_put_protocols_list <- function(ProtocolsList, TagList = NULL) {
  op <- new_operation(
    name = "PutProtocolsList",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$put_protocols_list_input(ProtocolsList = ProtocolsList, TagList = TagList)
  output <- .fms$put_protocols_list_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$put_protocols_list <- fms_put_protocols_list

#' Adds one or more tags to an AWS resource
#'
#' @description
#' Adds one or more tags to an AWS resource.
#'
#' @usage
#' fms_tag_resource(ResourceArn, TagList)
#'
#' @param ResourceArn &#91;required&#93; The Amazon Resource Name (ARN) of the resource to return tags for. The
#' AWS Firewall Manager resources that support tagging are policies,
#' applications lists, and protocols lists.
#' @param TagList &#91;required&#93; The tags to add to the resource.
#'
#' @return
#' An empty list.
#'
#' @section Request syntax:
#' ```
#' svc$tag_resource(
#'   ResourceArn = "string",
#'   TagList = list(
#'     list(
#'       Key = "string",
#'       Value = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_tag_resource
fms_tag_resource <- function(ResourceArn, TagList) {
  op <- new_operation(
    name = "TagResource",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$tag_resource_input(ResourceArn = ResourceArn, TagList = TagList)
  output <- .fms$tag_resource_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$tag_resource <- fms_tag_resource

#' Removes one or more tags from an AWS resource
#'
#' @description
#' Removes one or more tags from an AWS resource.
#'
#' @usage
#' fms_untag_resource(ResourceArn, TagKeys)
#'
#' @param ResourceArn &#91;required&#93; The Amazon Resource Name (ARN) of the resource to return tags for. The
#' AWS Firewall Manager resources that support tagging are policies,
#' applications lists, and protocols lists.
#' @param TagKeys &#91;required&#93; The keys of the tags to remove from the resource.
#'
#' @return
#' An empty list.
#'
#' @section Request syntax:
#' ```
#' svc$untag_resource(
#'   ResourceArn = "string",
#'   TagKeys = list(
#'     "string"
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname fms_untag_resource
fms_untag_resource <- function(ResourceArn, TagKeys) {
  op <- new_operation(
    name = "UntagResource",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .fms$untag_resource_input(ResourceArn = ResourceArn, TagKeys = TagKeys)
  output <- .fms$untag_resource_output()
  config <- get_config()
  svc <- .fms$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.fms$operations$untag_resource <- fms_untag_resource
